[![Datalayer](https://assets.datalayer.tech/datalayer-25.svg)](https://datalayer.io)

# Jupyter Kernels Docs

> Source code for the [Jupyter Kernels Documentation](https://datalayer.io), built with [Docusaurus](https://docusaurus.io).

```bash
# Install the dependencies.
make install
```

```bash
# Local Development: This command starts a local development server and opens up a browser window.
# Most changes are reflected live without having to restart the server.
echo open http://localhost:3000
make start
```

```bash
# Build: This command generates static content into the `build` directory
# and can be served using any static contents hosting service.
make build
```

```bash
# Publish if you have karma for.
make publish
```
